"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
require("core-js/modules/es.promise.js");
require("core-js/modules/es.json.stringify.js");
var _workflowDefinition = _interopRequireDefault(require("../DataModals/workflowDefinition.json"));
var _updateWorkflowDefinition = _interopRequireDefault(require("../DataModals/updateWorkflowDefinition.json"));
var _fetchResponseHandler = _interopRequireDefault(require("../helpers/fetchResponseHandler"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
const GetWorkflowDefinition = async function GetWorkflowDefinition(props) {
  let {
    page,
    size,
    processDefinitionId,
    API_URL,
    headers
  } = props;
  let query = "page=".concat(page, "&size=").concat(size);
  if (processDefinitionId) query = query + "&processDefinitionId=".concat(processDefinitionId);
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1?").concat(query);
  try {
    let response = await fetch(requestUrl, {
      method: "GET",
      headers: _objectSpread({}, headers)
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
const CreateWorkflowDefinition = async function CreateWorkflowDefinition(props) {
  let dataModal = _objectSpread({}, _workflowDefinition.default);
  let {
    processAcronym,
    processAllowedApplicationStatus,
    processCategory,
    processDescription,
    processName,
    processVersion,
    processTasksDefinition,
    sdkVersion,
    processCountry,
    API_URL,
    headers
  } = props;
  dataModal.processCountry = processCountry;
  dataModal.processAcronym = processAcronym;
  dataModal.processAllowedApplicationStatus = processAllowedApplicationStatus;
  dataModal.processCategory = processCategory;
  dataModal.processDescription = processDescription;
  dataModal.processName = processName;
  dataModal.processVersion = processVersion;
  dataModal.processTasksDefinition = processTasksDefinition;
  dataModal.sdkVersion = sdkVersion;
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1");
  try {
    let response = await fetch(requestUrl, {
      method: "POST",
      body: JSON.stringify(dataModal),
      headers: _objectSpread(_objectSpread({}, headers), {}, {
        "Content-Type": "application/json"
      })
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
const UpdateWorkflowDefinition = async function UpdateWorkflowDefinition(props) {
  let dataModal = _objectSpread({}, _updateWorkflowDefinition.default);
  let {
    processAcronym,
    processAllowedApplicationStatus,
    processCategory,
    processCountry,
    processDescription,
    processName,
    processVersion,
    sdkVersion,
    API_URL,
    headers,
    processCode
  } = props;
  dataModal.processAcronym = processAcronym;
  dataModal.processAllowedApplicationStatus = processAllowedApplicationStatus;
  dataModal.processCategory = processCategory;
  dataModal.processCountry = processCountry;
  dataModal.processDescription = processDescription;
  dataModal.processName = processName;
  dataModal.processVersion = processVersion;
  dataModal.sdkVersion = sdkVersion;
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1/").concat(processCode);
  try {
    let response = await fetch(requestUrl, {
      method: "PUT",
      body: JSON.stringify(dataModal),
      headers: _objectSpread(_objectSpread({}, headers), {}, {
        "Content-Type": "application/json"
      })
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
const UpdateWorkflowDefinitionTasks = async function UpdateWorkflowDefinitionTasks(props) {
  let {
    task,
    taskId,
    API_URL,
    headers,
    processCode
  } = props;
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1/").concat(processCode, "/").concat(taskId);
  try {
    let response = await fetch(requestUrl, {
      method: "PUT",
      body: JSON.stringify(task),
      headers: _objectSpread(_objectSpread({}, headers), {}, {
        "Content-Type": "application/json"
      })
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
const DeleteAllWorkflowDefinition = async function DeleteAllWorkflowDefinition(props) {
  let {
    API_URL,
    headers
  } = props;
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1");
  try {
    let response = await fetch(requestUrl, {
      method: "GET",
      headers: _objectSpread({}, headers)
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
const DeleteWorkflowDefinitionByProcessCode = async function DeleteWorkflowDefinitionByProcessCode(props) {
  let {
    processCode,
    API_URL,
    headers
  } = props;
  let requestUrl = "".concat(API_URL, "/digital-bpm/workflow-definition/v1/").concat(processCode);
  try {
    let response = await fetch(requestUrl, {
      method: "GET",
      headers: _objectSpread({}, headers)
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
var _default = {
  GetWorkflowDefinition,
  CreateWorkflowDefinition,
  UpdateWorkflowDefinition,
  UpdateWorkflowDefinitionTasks,
  DeleteAllWorkflowDefinition,
  DeleteWorkflowDefinitionByProcessCode
};
exports.default = _default;