"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SearchWorkflows = exports.ReassignTask = exports.ManageWorkflow = exports.GetWorkflowTaskDetail = exports.CreateWorkflow = exports.AssignTask = void 0;
require("core-js/modules/es.promise.js");
require("core-js/modules/es.json.stringify.js");
require("core-js/modules/web.dom-collections.iterator.js");
var Constants = _interopRequireWildcard(require("../constants"));
var _workflow = _interopRequireDefault(require("../DataModals/workflow.json"));
var _updateWorkflow = _interopRequireDefault(require("../DataModals/updateWorkflow.json"));
var _fetchResponseHandler = _interopRequireDefault(require("../helpers/fetchResponseHandler"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
const CreateWorkflow = async function CreateWorkflow(props) {
  let dataModal = _objectSpread({}, _workflow.default);
  let {
    applicationCode,
    country,
    applicationStatus,
    workflowSubject,
    workflowTasks,
    workflowUserGroup,
    workflowCreatedBy,
    processFilterParameters,
    workflowName,
    workflowDefId,
    API_URL
  } = props;
  dataModal.applicationCode = applicationCode;
  dataModal.country = country;
  dataModal.applicationStatus = applicationStatus;
  dataModal.workflowSubject = workflowSubject;
  dataModal.workflowTasks.push(workflowTasks);
  dataModal.workflowUserGroup = workflowUserGroup;
  dataModal.workflowCreatedBy = workflowCreatedBy;
  dataModal.processFilterParameters = processFilterParameters;
  dataModal.workflowName = workflowName;
  dataModal.workflowDefId = workflowDefId;
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/workflow");
  try {
    let response = await fetch(requestUrl, {
      method: "POST",
      body: JSON.stringify(dataModal),
      headers: {
        "Content-Type": "application/json"
      }
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.CreateWorkflow = CreateWorkflow;
const ManageWorkflow = async function ManageWorkflow(props) {
  const {
    currentTask,
    newTask,
    taskAction,
    updatedBy,
    workflowId,
    API_URL
  } = props;
  let dataModal = _objectSpread({}, _updateWorkflow.default);
  dataModal.currentTask = currentTask;
  dataModal.newTask = newTask;
  dataModal.taskAction = taskAction;
  dataModal.updatedBy = updatedBy;
  dataModal.workflowId = workflowId;
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/manage-task");
  try {
    let response = await fetch(requestUrl, {
      method: "PUT",
      body: JSON.stringify(dataModal),
      headers: {
        "Content-Type": "application/json"
      }
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.ManageWorkflow = ManageWorkflow;
const SearchWorkflows = async function SearchWorkflows(props) {
  const {
    limit,
    offset,
    fromDate,
    toDate,
    workFlowStatus,
    taskUserName,
    taskUserGroup,
    keys,
    workFlowName,
    country,
    API_URL
  } = props;
  let query = "page=".concat(offset, "&size=").concat(limit);
  if (taskUserGroup) query = query + "&taskUserGroup=".concat(taskUserGroup);
  if (taskUserName) query = query + "&taskUserName=".concat(taskUserName);
  if (workFlowStatus) query = query + "&workFlowStatus=".concat(workFlowStatus);
  if (fromDate) query = query + "&fromDate=".concat(fromDate);
  if (toDate) query = query + "&toDate=".concat(toDate);
  if (workFlowName) query = query + "&workFlowName=".concat(workFlowName);
  if (workflowDefId) query = query + "&workflowDefId=".concat(workflowDefId);
  if (keys.length > 0) {
    for (let i = 0; i < keys.length; i++) {
      if (keys[i]) query = query + "&key".concat(i + 1, "=").concat(keys[i]);
    }
  }
  if (country) query = query + "&workFlowCountry=".concat(country);
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/search?").concat(query);
  try {
    let response = await fetch(requestUrl, {
      method: "GET",
      headers: {}
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.SearchWorkflows = SearchWorkflows;
const GetWorkflowTaskDetail = async function GetWorkflowTaskDetail(props) {
  let {
    workFlowId,
    taskId,
    API_URL
  } = props;
  let query = "";
  if (workFlowId) query += "&workFlowId= ".concat(workFlowId);
  if (taskId) query += "&taskId= ".concat(taskId);
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/task-details?page=0&size=1").concat(query);
  try {
    let response = await fetch(requestUrl, {
      method: "GET",
      headers: {}
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.GetWorkflowTaskDetail = GetWorkflowTaskDetail;
const AssignTask = async function AssignTask(props) {
  let {
    userName,
    taskId,
    workflowId,
    updatedBy,
    API_URL
  } = props;
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/assign-task");
  try {
    let response = await fetch(requestUrl, {
      method: "PUT",
      headers: {
        "Content-Type": "application/json"
      },
      body: JSON.stringify({
        action: "CLAIM",
        taskId: taskId,
        updatedBy: updatedBy,
        userName: userName,
        workflowId: workflowId
      })
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.AssignTask = AssignTask;
const ReassignTask = async function ReassignTask(props) {
  let {
    userName,
    taskId,
    workflowId,
    updatedBy,
    API_URL
  } = props;
  let requestUrl = "".concat(API_URL, "/").concat(Constants.BASE_PATH, "/engine/v1/reassign-tasks");
  try {
    let response = await fetch(requestUrl, {
      method: "PUT",
      headers: {
        "Content-Type": "application/json"
      },
      body: JSON.stringify({
        requests: [{
          taskId: taskId,
          userName: userName
        }],
        updatedBy: updatedBy,
        workflowId: workflowId
      })
    });
    let result = await (0, _fetchResponseHandler.default)(response);
    return result;
  } catch (e) {
    throw e;
  }
};
exports.ReassignTask = ReassignTask;